@@ -1,4 +1,4 @@
-(* $Id$
+(* $Id: shell_sys.ml 50 2004-10-03 17:06:28Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -123,6 +123,7 @@ exception Fatal_error of exn;;
 type command =
     { mutable c_cmdname     : string;
       mutable c_arguments   : string array;
+      mutable c_directory   : string option;
       mutable c_environment : environment;
       mutable c_descriptors : U.file_descr list;
       mutable c_assignments : (U.file_descr * U.file_descr) list;
@@ -133,6 +134,7 @@ type command =
 let command
       ?cmdname
       ?(arguments = [||])
+      ?chdir
       ?(environment = current_env())
       ?(descriptors = [ U.stdin; U.stdout; U.stderr ])
       ?(assignments = [])
@@ -148,6 +150,7 @@ let command
   in
   { c_cmdname = cmdname';
     c_arguments = arguments;
+    c_directory = chdir;
     c_environment = environment;
     c_descriptors = descriptors;
     c_assignments = assignments;
@@ -157,6 +160,7 @@ let command
 
 let get_cmdname     c = c.c_cmdname     ;;
 let get_arguments   c = c.c_arguments   ;;
+let get_chdir       c = c.c_directory   ;;
 let get_environment c = c.c_environment ;;
 let get_descriptors c = c.c_descriptors ;;
 let get_assignments c = c.c_assignments ;;
@@ -164,6 +168,7 @@ let get_filename    c = c.c_filename    ;;
 
 let set_cmdname     c x = c.c_cmdname     <- x ;;
 let set_arguments   c x = c.c_arguments   <- x ;;
+let set_chdir       c x = c.c_directory   <- x ;;
 let set_environment c x = c.c_environment <- x ;;
 let set_descriptors c x = c.c_descriptors <- x ;;
 let set_assignments c x = c.c_assignments <- x ;;
@@ -172,6 +177,7 @@ let set_filename    c x = c.c_filename    <- x ;;
 let copy_command c =
   { c_cmdname     = String.copy c.c_cmdname;
     c_arguments   = Array.map String.copy c.c_arguments;
+    c_directory   = c.c_directory;
     c_environment = copy_env c.c_environment;
     c_descriptors = c.c_descriptors;
     c_assignments = c.c_assignments;
@@ -399,6 +405,11 @@ let run
 
       try
 
+	( match c.c_directory with
+	      None -> ()
+	    | Some d -> Unix.chdir d
+	);
+
         (* Close control_in such that the parent process can detect EOF: *)
 
         U.close control_in;
