@@ -1,4 +1,4 @@
-(* $Id$
+(* $Id: shell_sys.mli 50 2004-10-03 17:06:28Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
@@ -88,6 +88,7 @@ type command
 val command :
       ?cmdname:string ->                   (* default: derived from filename *)
       ?arguments:(string array) ->         (* default: empty *)
+      ?chdir:string ->                     (* default: current working dir *)
       ?environment:environment ->          (* default: current environment *)
       ?descriptors:(Unix.file_descr list) -> 
                                            (* default: stdin, stdout, stderr *)
@@ -105,6 +106,8 @@ val command :
    *   default, this argument is derived from [filename].
    * @param arguments The arguments of the command (starting with the
    *   first real argument, skipping [cmdname]). By default [ [] ].
+   * @param chdir Before the command is executed it is changed to
+   *   this directory.
    * @param environment The environment of the command. By default, the
    *   current environment
    * @param assignments A list of descriptor pairs [ (fd_from,fd_to) ].
@@ -152,6 +155,9 @@ val get_cmdname     : command -> string
 val get_arguments   : command -> string array
   (** Returns the argument array of the command (skipping the command name) *)
 
+val get_chdir       : command -> string option
+  (** Returns the [chdir] parameter of the command *)
+
 val get_environment : command -> environment
   (** Returns the designated environment of the command *)
 
@@ -170,6 +176,9 @@ val set_cmdname     : command -> string          -> unit
 val set_arguments   : command -> string array    -> unit
   (** Sets the argument array *)
 
+val set_chdir       : command -> string option   -> unit
+  (** Sets the [chdir] parameter of the command *)
+
 val set_environment : command -> environment     -> unit
   (** Sets the environment *)
 
